@@ -64,6 +64,3 @@ find(
   },
   $test_default_dir
 );
-
-# Add spvm_build directory
-mkdir 't/precompile/spvm_build';
